@@ -46,7 +46,7 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
         theme(panel.grid.major = element_blank(),
               panel.grid.minor = element_blank(),
               axis.line = element_line(size = 0.25, colour = "black"),
-              plot.title = element_text(size = 16),
+              plot.title = element_text(size = 16, hjust = 0.5),
               panel.border = element_rect(colour = "black", fill = NA)) +
         ggtitle("Output of best model") +
         ylab("Biological variable")
@@ -74,7 +74,7 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
             theme(panel.grid.major = element_blank(),
                   panel.grid.minor = element_blank(),
                   axis.line = element_line(size = 0.25, colour = "black"),
-                  plot.title = element_text(size = 16),
+                  plot.title = element_text(size = 16, hjust = 0.5),
                   panel.border = element_rect(colour = "black", fill = NA)) +
             ggtitle("Output of best model") +
             ylab("Biological variable") +    
@@ -122,7 +122,7 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
             theme(panel.grid.major = element_blank(),
                   panel.grid.minor = element_blank(),
                   axis.line = element_line(size = 0.25, colour = "black"),
-                  plot.title = element_text(size = 16),
+                  plot.title = element_text(size = 16, hjust = 0.5),
                   panel.border = element_rect(colour = "black", fill = NA)) +
             ggtitle("Output of best model") +
             ylab("Biological variable") +    
@@ -149,7 +149,7 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
             theme(panel.grid.major = element_blank(),
                   panel.grid.minor = element_blank(),
                   axis.line = element_line(size = 0.25, colour = "black"),
-                  plot.title = element_text(size = 16),
+                  plot.title = element_text(size = 16, hjust = 0.5),
                   panel.border = element_rect(colour = "black", fill = NA)) +
             ggtitle("Output of best model") +
             ylab("Biological variable") +    
@@ -197,7 +197,7 @@ plotbest <- function(dataset, bestmodel, bestmodeldata){
             theme(panel.grid.major = element_blank(),
                   panel.grid.minor = element_blank(),
                   axis.line = element_line(size = 0.25, colour = "black"),
-                  plot.title = element_text(size = 16),
+                  plot.title = element_text(size = 16, hjust = 0.5),
                   panel.border = element_rect(colour = "black", fill = NA)) +
             ggtitle("Output of best model") +
             ylab("Biological variable") +    
