@@ -23,10 +23,14 @@
 #'  (e.g. number of days before a set point in time).
 #'@param refday If type is absolute, the day and month respectively of the 
 #'  year from which the absolute window analysis will start.
-#'@param cmissing TRUE or FALSE, determines what should be done if there are 
-#'  missing climate data. If FALSE, the function will not run if missing 
-#'  climate data is encountered. If TRUE, any records affected by missing 
-#'  climate data will be removed from climate window analysis.
+#'@param cmissing cmissing Determines what should be done if there are 
+#'  missing climate data. Three approaches are possible: 
+#'   - FALSE; the function will not run if missing climate data is encountered.
+#'   An object 'missing' will be returned containing the dates of missing climate.
+#'   - "method1"; missing climate data will be replaced with the mean climate
+#'   of the preceding and following 2 days.
+#'   - "method2"; missing climate data will be replaced with the mean climate
+#'   of all records on the same date.
 #'@param cinterval The resolution at which climate window analysis will be 
 #'  conducted. May be days ("day"), weeks ("week"), or months ("month"). Note the units
 #'  of parameter 'range' will differ depending on the choice
@@ -46,7 +50,7 @@
 #'  1. The variable used for mean centring (e.g. Year, Site, Individual). 
 #'  Please specify the parent environment and variable name (e.g. Biol$Year).
 #'  2. Whether the model should include both within-group means and variance ("both"),
-#'  only within-group means ("mean"), or only within-group variance ("var").
+#'  only within-group means ("mean"), or only within-group variance ("dev").
 #'@param cohort A variable used to group biological records that occur in the same biological
 #'  season but cover multiple years (e.g. southern hemisphere breeding season). Only required
 #'  when type is "absolute". The cohort variable should be in the same dataset as the variable bdate.
@@ -382,10 +386,91 @@ singlewin <- function(xvar, cdate, bdate, baseline,
            See object missing for all missing climate data"))
   }
   
-  if (cmissing == TRUE && length(which(is.na(cmatrix))) > 0){
-    modeldat      <- modeldat[complete.cases(cmatrix), ]
-    baseline      <- update(baseline, yvar~., data = modeldat)
-    cmatrix       <- cmatrix[complete.cases(cmatrix), ]
+  if (cmissing != FALSE && length(which(is.na(cmatrix))) > 0){
+    
+    print("Missing climate data detected. Please wait while appropriate data is calculated to replace NAs.")
+    
+    if(cmissing == "method1"){
+      
+      for(i in which(is.na(cmatrix))){
+        
+        cmatrix[i] <- mean(c(cmatrix[i - (1:2)], cmatrix[i + (1:2)]), na.rm = T)
+        
+        if(is.na(cmatrix[i])){
+          
+          stop("Too many consecutive NAs present in the data. Consider using method2 or manually replacing NAs.")
+          
+        }
+        
+      }
+      
+    } else if(cmissing == "method2"){
+      
+      cdate_new <- data.frame(Date = as.Date(cdate, format = "%d/%m/%Y"),
+                              Year  = lubridate::year(as.Date(cdate, format = "%d/%m/%Y")),
+                              Month = lubridate::month(as.Date(cdate, format = "%d/%m/%Y")),
+                              Day   = lubridate::day(as.Date(cdate, format = "%d/%m/%Y")))
+      
+      if(cinterval == "week"){
+        
+        for(j in 1:nrow(cdate_new)){
+          
+          cdate_new$Week[j] <- ceiling((as.numeric(cdate_new$Date[j]) - min(as.numeric(subset(cdate_new, cdate_new$Year == cdate_new$Year[j])$Date)) + 1) / 7)
+          
+        }
+        
+      }
+      
+      for(i in which(is.na(cmatrix))){
+        
+        col <- floor(i/nrow(cmatrix))
+        
+        if(is.null(spatial)){
+          
+          brecord <- bintno[i - col*nrow(cmatrix)] - (range[2] + col) - 1
+          
+        } else {
+          
+          brecord <- bintno$Date[i - col*nrow(cmatrix)] - (range[2] + col) - 1
+          
+        }
+        
+        min_date <- min(as.Date(cdate, format = "%d/%m/%Y"))
+        
+        if(cinterval == "day"){
+          
+          missing_rec <- as.Date(brecord, format = "%d/%m/%Y", origin = min_date)
+          
+          cmatrix[i] <- mean(xvar[which(cdate_new$Month == lubridate::month(missing_rec) & cdate_new$Day == lubridate::day(missing_rec))], na.rm = T)
+          
+        } else if(cinterval == "week"){
+          
+          missing_week <- ceiling(((as.numeric((as.Date(bdate[i - col*nrow(cmatrix)], format = "%d/%m/%Y"))) - (col*7)) - as.numeric(as.Date(paste("01/01/", lubridate::year(as.Date(bdate[i - col*nrow(cmatrix)], format = "%d/%m/%Y")), sep = ""), format = "%d/%m/%Y")) + 1) / 7)
+          
+          cmatrix[i] <- mean(xvar[which(cdate_new$Week == missing_week)], na.rm = T)
+          
+        } else if(cinterval == "month"){
+          
+          missing_month <- (lubridate::month(min(as.Date(cdate, format = "%d/%m/%Y"))) + (which(is.na(xvar)) - 1)) - (floor((lubridate::month(min(as.Date(cdate, format = "%d/%m/%Y"))) + (which(is.na(xvar)) - 1))/12)*12)
+          
+          cmatrix[i] <- mean(xvar[which(cdate_new$Month == missing_month)], na.rm = T)
+          
+        }
+        
+        if(is.na(cmatrix[i])){
+          
+          stop("There is no data available for certain climate records across all years. Consider using method1 or manually replacing NAs.")
+          
+        }
+        
+      }
+      
+    } else {
+      
+      stop("cmissing should be FALSE, 'method1' or 'method2'")
+      
+    }
+    
   }
   
   modeldat           <- model.frame(baseline)
